import { base58 } from './utils/bytes.mjs';

const publicKey = input => {
  // PublicKeyBase58.
  if (typeof input === 'string') {
    return {
      bytes: base58.serialize(input)
    };
  }
  // { publicKey: PublicKey }.
  if (typeof input === 'object' && 'publicKey' in input) {
    return {
      bytes: new Uint8Array(input.publicKey.bytes)
    };
  }
  // PublicKey.
  if (isPublicKey(input)) {
    return {
      bytes: new Uint8Array(input.bytes)
    };
  }
  // PublicKeyBytes.
  return {
    bytes: input
  };
};
const defaultPublicKey = () => publicKey('11111111111111111111111111111111');
const isPublicKey = value => typeof value === 'object' && typeof value.bytes === 'object' && typeof value.bytes.BYTES_PER_ELEMENT === 'number' && typeof value.bytes.length === 'number' && value.bytes.BYTES_PER_ELEMENT === 1 && value.bytes.length === 32;
const isPda = value => typeof value === 'object' && typeof value.bump === 'number' && isPublicKey(value);
const samePublicKey = (left, right) => left.bytes.toString() === right.bytes.toString();
const formatPublicKey = publicKey => base58.deserialize(publicKey.bytes)[0];
const checkForIsWritableOverride = (account, value) => 'isWritable' in account && typeof account.isWritable === 'boolean' ? account.isWritable : value;

export { checkForIsWritableOverride, defaultPublicKey, formatPublicKey, isPda, isPublicKey, publicKey, samePublicKey };
//# sourceMappingURL=PublicKey.mjs.map
